char applemac_2_ansi[128][3] = {
"C4", "C5", "C7", "C9", "D1", "D6", "DC", "E1", 
"E0", "E2", "E4", "E3", "E5", "E7", "E9", "E8", 
"EA", "EB", "ED", "EC", "EE", "EF", "F1", "F3", 
"F2", "F4", "F6", "F5", "FA", "F9", "FB", "FC", 
"86", "B0", "A2", "A3", "A7", "95", "B6", "DF", 
"AE", "A9", "99", "B4", "A8", "00", "C6", "D8", 
"00", "B1", "00", "00", "A5", "B5", "00", "00", 
"00", "00", "00", "AA", "BA", "00", "E6", "F8", 
"BF", "A1", "AC", "00", "83", "00", "00", "AB", 
"BB", "85", "A0", "C0", "C3", "D5", "8C", "9C", 
"96", "97", "93", "94", "91", "92", "F7", "00", 
"FF", "9F", "00", "A4", "8B", "9B", "00", "00", 
"87", "B7", "82", "84", "89", "C2", "CA", "C1", 
"CB", "C8", "CD", "CE", "CF", "CC", "D3", "D4", 
"00", "D2", "DA", "DB", "D9", "00", "88", "98", 
"AF", "00", "00", "00", "B8", "00", "00", "00", 
};
char applemac_2_sym[128][3] = {
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "B0", "00", "00", "00", "B7", "00", "00", 
"D2", "D3", "D4", "00", "00", "B9", "00", "00", 
"A5", "B1", "A3", "B3", "00", "00", "B6", "E5", 
"D5", "70", "F2", "00", "00", "57", "00", "00", 
"00", "00", "D8", "D6", "A6", "BB", "44", "00", 
"00", "BC", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "B8", "E0", 
"00", "00", "A4", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
};
char cp437_2_ansi[128][3] = {
"C7", "FC", "E9", "E2", "E4", "E0", "E5", "E7", 
"EA", "EB", "E8", "EF", "EE", "EC", "C4", "C5", 
"C9", "E6", "C6", "F4", "F6", "F2", "FB", "F9", 
"FF", "D6", "DC", "A2", "A3", "A5", "00", "00", 
"E1", "ED", "F3", "FA", "F1", "D1", "AA", "BA", 
"BF", "00", "AC", "BD", "BC", "A1", "AB", "BB", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "B1", "00", "00", "00", "00", "F7", "00", 
"00", "B7", "00", "00", "00", "B2", "00", "A0", 
};
char cp437_2_sym[128][3] = {
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "D8", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"61", "62", "47", "70", "53", "73", "6D", "74", 
"46", "51", "57", "64", "A5", "C6", "65", "C7", 
"BA", "B1", "B3", "A3", "F3", "F5", "B8", "BB", 
"00", "00", "00", "D6", "00", "00", "00", "00", 
};
char cp850_2_ansi[128][3] = {
"C7", "FC", "E9", "E2", "E4", "E0", "E5", "E7", 
"EA", "EB", "E8", "EF", "EE", "EC", "C4", "C5", 
"C9", "E6", "C6", "F4", "F6", "F2", "FB", "F9", 
"FF", "D6", "DC", "F8", "A3", "D8", "D7", "00", 
"E1", "ED", "F3", "FA", "F1", "D1", "AA", "BA", 
"BF", "AE", "AC", "BD", "BC", "A1", "AB", "BB", 
"00", "00", "00", "00", "00", "C1", "C2", "C0", 
"A9", "00", "00", "00", "00", "A2", "A5", "00", 
"00", "00", "00", "00", "00", "00", "E3", "C3", 
"00", "00", "00", "00", "00", "00", "00", "A4", 
"F0", "D0", "CA", "CB", "C8", "00", "CD", "CE", 
"CF", "00", "00", "00", "00", "A6", "CC", "00", 
"D3", "DF", "D4", "D2", "F5", "D5", "00", "DE", 
"FE", "DA", "DB", "D9", "FD", "DD", "97", "B4", 
"AD", "B1", "00", "BE", "B6", "A7", "F7", "00", 
"B0", "A8", "00", "B9", "B3", "B2", "00", "A0", 
};
char cp850_2_sym[128][3] = {
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "B4", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "D2", "D8", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"D3", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "6D", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "B1", "DB", "00", "00", "00", "B8", "00", 
"B0", "00", "00", "00", "00", "00", "00", "00", 
};
char cp852_2_ansi[128][3] = {
"C7", "FC", "E9", "E2", "E4", "00", "00", "E7", 
"00", "EB", "00", "00", "EE", "00", "C4", "00", 
"C9", "00", "00", "F4", "F6", "00", "00", "00", 
"00", "D6", "DC", "00", "00", "00", "D7", "00", 
"E1", "ED", "F3", "FA", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "AB", "BB", 
"00", "00", "00", "00", "00", "C1", "C2", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "A4", 
"00", "00", "00", "CB", "00", "00", "CD", "DB", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"D3", "DF", "D4", "00", "00", "00", "8A", "9A", 
"00", "DA", "00", "00", "FD", "DD", "00", "B4", 
"AD", "00", "B8", "00", "00", "A7", "F7", "00", 
"B0", "A8", "00", "00", "00", "00", "00", "A0", 
};
char cp852_2_sym[128][3] = {
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "B4", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "B8", "00", 
"B0", "00", "00", "00", "00", "00", "00", "00", 
};
char cp852_2_1250[256][3] = {
"C7", "FC", "E9", "E2", "E4", "F9", "E6", "E7", 
"B3", "EB", "D5", "F5", "EE", "8F", "C4", "C6", 
"C9", "C5", "E5", "F4", "F6", "BC", "BE", "8C", 
"9C", "D6", "DC", "8D", "9D", "A3", "D7", "E8", 
"E1", "ED", "F3", "FA", "A5", "B9", "8E", "9E", 
"CA", "EA", "00", "9F", "C8", "BA", "AB", "BB", 
"00", "00", "00", "00", "00", "C1", "C2", "CC", 
"AA", "00", "00", "00", "00", "AF", "BF", "00", 
"00", "00", "00", "00", "00", "00", "C3", "E3", 
"00", "00", "00", "00", "00", "00", "00", "A4", 
"F0", "D0", "CF", "CB", "EF", "D2", "CD", "CE", 
"EC", "00", "00", "00", "00", "DE", "D9", "00", 
"D3", "DF", "D4", "D1", "F1", "F2", "8A", "9A", 
"C0", "DA", "E0", "DB", "FD", "DD", "FE", "B4", 
"AD", "BD", "B2", "A1", "A2", "A7", "F7", "B8", 
"B0", "A8", "FF", "FB", "D8", "F8", "00", "A0", 
};
char cp865_2_ansi[128][3] = {
"C7", "FC", "E9", "E2", "E4", "E0", "E5", "E7", 
"EA", "EB", "E8", "EF", "EE", "EC", "C4", "C5", 
"C9", "E6", "C6", "F4", "F6", "F2", "FB", "F9", 
"FF", "D6", "DC", "F8", "A3", "D8", "00", "00", 
"E1", "ED", "F3", "FA", "F1", "D1", "AA", "BA", 
"BF", "00", "AC", "BD", "BC", "A1", "AB", "BB", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "B1", "00", "00", "00", "00", "F7", "00", 
"00", "B7", "00", "00", "00", "B2", "00", "A0", 
};
char cp865_2_sym[128][3] = {
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "D8", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"61", "62", "47", "70", "53", "73", "6D", "74", 
"46", "51", "57", "64", "A5", "C6", "65", "C7", 
"BA", "B1", "B3", "A3", "F3", "F5", "B8", "BB", 
"00", "00", "00", "D6", "00", "00", "00", "00", 
};
char cp1250_2_ansi[128][3] = {
"00", "00", "82", "00", "84", "85", "86", "87", 
"00", "89", "8A", "8B", "00", "00", "00", "00", 
"00", "91", "92", "93", "94", "95", "96", "97", 
"00", "99", "9A", "9B", "00", "00", "00", "00", 
"A0", "00", "00", "00", "A4", "00", "A6", "A7", 
"A8", "A9", "00", "AB", "00", "AD", "AE", "00", 
"B0", "B1", "00", "00", "B4", "B5", "B6", "B7", 
"B8", "00", "00", "BB", "00", "00", "00", "00", 
"00", "C1", "C2", "00", "C4", "00", "00", "C7", 
"00", "C9", "00", "CB", "00", "CD", "CE", "00", 
"00", "00", "00", "D3", "D4", "00", "D6", "D7", 
"00", "00", "DA", "00", "DC", "DD", "00", "DF", 
"00", "E1", "E2", "00", "E4", "00", "00", "E7", 
"00", "E9", "00", "EB", "00", "ED", "EE", "00", 
"00", "00", "00", "F3", "F4", "00", "F6", "F7", 
"00", "00", "FA", "00", "FC", "FD", "00", "00", 
};
char cp1250_2_sym[128][3] = {
"00", "00", "00", "00", "00", "BC", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "B7", "00", "00", 
"00", "D4", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "D3", "00", "00", "00", "00", "D2", "00", 
"B0", "B1", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "B4", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "B8", 
"00", "00", "00", "00", "00", "00", "00", "00", 
};
char cp1250_2_1250[256][3] = {
"80", "00", "82", "00", "84", "85", "86", "87", 
"00", "89", "8A", "8B", "8C", "8D", "8E", "8F", 
"00", "91", "92", "93", "94", "95", "96", "97", 
"00", "99", "9A", "9B", "9C", "9D", "9E", "9F", 
"A0", "A1", "A2", "A3", "A4", "A5", "A6", "A7", 
"A8", "A9", "AA", "AB", "00", "AD", "AE", "AF", 
"B0", "B1", "B2", "B3", "B4", "B5", "B6", "B7", 
"B8", "B9", "BA", "BB", "BC", "BD", "BE", "BF", 
"C0", "C1", "C2", "C3", "C4", "C5", "C6", "C7", 
"C8", "C9", "CA", "CB", "CC", "CD", "CE", "CF", 
"D0", "D1", "D2", "D3", "D4", "D5", "D6", "D7", 
"D8", "D9", "DA", "DB", "DC", "DD", "DE", "DF", 
"E0", "E1", "E2", "E3", "E4", "E5", "E6", "E7", 
"E8", "E9", "EA", "EB", "EC", "ED", "EE", "EF", 
"F0", "F1", "F2", "F3", "F4", "F5", "F6", "F7", 
"F8", "F9", "FA", "FB", "FC", "FD", "FE", "FF", 
};
char cp1252_2_ansi[128][3] = {
"00", "00", "82", "83", "84", "85", "86", "87", 
"88", "89", "8A", "8B", "8C", "00", "00", "00", 
"00", "91", "92", "93", "94", "95", "96", "97", 
"98", "99", "9A", "9B", "9C", "00", "00", "9F", 
"A0", "A1", "A2", "A3", "A4", "A5", "A6", "A7", 
"A8", "A9", "AA", "AB", "AC", "AD", "AE", "AF", 
"B0", "B1", "B2", "B3", "B4", "B5", "B6", "B7", 
"B8", "B9", "BA", "BB", "BC", "BD", "BE", "BF", 
"C0", "C1", "C2", "C3", "C4", "C5", "C6", "C7", 
"C8", "C9", "CA", "CB", "CC", "CD", "CE", "CF", 
"D0", "D1", "D2", "D3", "D4", "D5", "D6", "D7", 
"D8", "D9", "DA", "DB", "DC", "DD", "DE", "DF", 
"E0", "E1", "E2", "E3", "E4", "E5", "E6", "E7", 
"E8", "E9", "EA", "EB", "EC", "ED", "EE", "EF", 
"F0", "F1", "F2", "F3", "F4", "F5", "F6", "F7", 
"F8", "F9", "FA", "FB", "FC", "FD", "FE", "FF", 
};
char cp1252_2_sym[128][3] = {
"00", "00", "00", "A6", "00", "BC", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "B7", "00", "00", 
"00", "D4", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "D3", "00", "00", "D8", "00", "D2", "00", 
"B0", "B1", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "B4", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "B8", 
"00", "00", "00", "00", "00", "00", "00", "00", 
};
char decmulti_2_ansi[128][3] = {
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "A1", "A2", "A3", "00", "A5", "00", "A7", 
"A4", "A9", "AA", "AB", "00", "00", "00", "00", 
"B0", "B1", "B2", "B3", "00", "B5", "B6", "B7", 
"00", "B9", "BA", "BB", "BC", "BD", "00", "BF", 
"C0", "C1", "C2", "C3", "C4", "C5", "C6", "C7", 
"C8", "C9", "CA", "CB", "CC", "CD", "CE", "CF", 
"00", "D1", "D2", "D3", "D4", "D5", "D6", "8C", 
"D8", "D9", "DA", "DB", "DC", "9F", "00", "DF", 
"E0", "E1", "E2", "E3", "E4", "E5", "E6", "E7", 
"E8", "E9", "EA", "EB", "EC", "ED", "EE", "EF", 
"00", "F1", "F2", "F3", "F4", "F5", "F6", "9C", 
"F8", "F9", "FA", "FB", "FC", "FF", "00", "00", 
};
char decmulti_2_sym[128][3] = {
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "D3", "00", "00", "00", "00", "00", "00", 
"B0", "B1", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
};
char latin1_2_ansi[128][3] = {
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"A0", "A1", "A2", "A3", "A4", "A5", "A6", "A7", 
"A8", "A9", "AA", "AB", "AC", "AD", "AE", "AF", 
"B0", "B1", "B2", "B3", "B4", "B5", "B6", "B7", 
"B8", "B9", "BA", "BB", "BC", "BD", "BE", "BF", 
"C0", "C1", "C2", "C3", "C4", "C5", "C6", "C7", 
"C8", "C9", "CA", "CB", "CC", "CD", "CE", "CF", 
"D0", "D1", "D2", "D3", "D4", "D5", "D6", "D7", 
"D8", "D9", "DA", "DB", "DC", "DD", "DE", "DF", 
"E0", "E1", "E2", "E3", "E4", "E5", "E6", "E7", 
"E8", "E9", "EA", "EB", "EC", "ED", "EE", "EF", 
"F0", "F1", "F2", "F3", "F4", "F5", "F6", "F7", 
"F8", "F9", "FA", "FB", "FC", "FD", "FE", "FF", 
};
char latin1_2_sym[128][3] = {
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "D3", "00", "00", "D8", "00", "D2", "00", 
"B0", "B1", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "B4", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "B8", 
"00", "00", "00", "00", "00", "00", "00", "00", 
};
char latin2_2_ansi[128][3] = {
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"A0", "00", "00", "00", "A4", "00", "00", "A7", 
"A8", "8A", "00", "00", "00", "AD", "00", "00", 
"B0", "00", "00", "00", "B4", "00", "00", "00", 
"B8", "9A", "00", "00", "00", "00", "00", "00", 
"00", "C1", "C2", "00", "C4", "00", "00", "C7", 
"00", "C9", "00", "CB", "00", "CD", "CE", "00", 
"00", "00", "00", "D3", "D4", "00", "D6", "D7", 
"00", "00", "DA", "00", "DC", "DD", "00", "DF", 
"00", "E1", "E2", "00", "E4", "00", "00", "E7", 
"00", "E9", "00", "EB", "00", "ED", "EE", "00", 
"00", "00", "00", "F3", "F4", "00", "F6", "F7", 
"00", "00", "FA", "00", "FC", "FD", "00", "00", 
};
char latin2_2_sym[128][3] = {
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"B0", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "B4", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "B8", 
"00", "00", "00", "00", "00", "00", "00", "00", 
};
char latin2_2_1250[256][3] = {
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"A0", "A5", "A2", "A3", "A4", "BC", "8C", "A7", 
"A8", "8A", "AA", "8D", "8F", "AD", "8E", "AF", 
"B0", "B9", "B2", "B3", "B4", "BE", "9C", "A1", 
"B8", "9A", "BA", "9D", "9F", "BD", "9E", "BF", 
"C0", "C1", "C2", "C3", "C4", "C5", "C6", "C7", 
"C8", "C9", "CA", "CB", "CC", "CD", "CE", "CF", 
"D0", "D1", "D2", "D3", "D4", "D5", "D6", "D7", 
"D8", "D9", "DA", "DB", "DC", "DD", "DE", "DF", 
"E0", "E1", "E2", "E3", "E4", "E5", "E6", "E7", 
"E8", "E9", "EA", "EB", "EC", "ED", "EE", "EF", 
"F0", "F1", "F2", "F3", "F4", "F5", "F6", "F7", 
"F8", "F9", "FA", "FB", "FC", "FD", "FE", "FF", 
};

char latin3_2_ansi[128][3] = {
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"A0", "00", "00", "A3", "A4", "00", "00", "A7", 
"A8", "00", "00", "00", "00", "AD", "00", "00", 
"B0", "00", "B2", "B3", "B4", "B5", "00", "B7", 
"B8", "00", "00", "00", "00", "BD", "00", "00", 
"C0", "C1", "C2", "00", "C4", "00", "00", "C7", 
"C8", "C9", "CA", "CB", "CC", "CD", "CE", "CF", 
"00", "D1", "D2", "D3", "D4", "00", "D6", "D7", 
"00", "D9", "DA", "DB", "DC", "00", "00", "DF", 
"E0", "E1", "E2", "00", "E4", "00", "00", "E7", 
"E8", "E9", "EA", "EB", "EC", "ED", "EE", "EF", 
"00", "F1", "F2", "F3", "F4", "00", "F6", "F7", 
"00", "F9", "FA", "FB", "FC", "00", "00", "00", 
};
char latin3_2_sym[128][3] = {
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"B0", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "B4", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "B8", 
"00", "00", "00", "00", "00", "00", "00", "00", 
};
char latin4_2_ansi[128][3] = {
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"A0", "00", "00", "00", "A4", "00", "00", "A7", 
"A8", "8A", "00", "00", "00", "AD", "00", "AF", 
"B0", "00", "00", "00", "B4", "00", "00", "00", 
"B8", "9A", "00", "00", "00", "00", "00", "00", 
"00", "C1", "C2", "C3", "C4", "C5", "C6", "00", 
"00", "C9", "00", "CB", "00", "CD", "CE", "00", 
"00", "00", "00", "00", "D4", "D5", "D6", "D7", 
"D8", "00", "DA", "DB", "DC", "00", "00", "DF", 
"00", "E1", "E2", "E3", "E4", "E5", "E6", "00", 
"00", "E9", "00", "EB", "00", "ED", "EE", "00", 
"00", "00", "00", "00", "F4", "F5", "F6", "F7", 
"F8", "00", "FA", "FB", "FC", "00", "00", "00", 
};
char latin4_2_sym[128][3] = {
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"B0", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "B4", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "B8", 
"00", "00", "00", "00", "00", "00", "00", "00", 
};
char latin5_2_ansi[128][3] = {
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"A0", "A1", "A2", "A3", "A4", "A5", "A6", "A7", 
"A8", "A9", "AA", "AB", "AC", "AD", "AE", "AF", 
"B0", "B1", "B2", "B3", "B4", "B5", "B6", "B7", 
"B8", "B9", "BA", "BB", "BC", "BD", "BE", "BF", 
"C0", "C1", "C2", "C3", "C4", "C5", "C6", "C7", 
"C8", "C9", "CA", "CB", "CC", "CD", "CE", "CF", 
"00", "D1", "D2", "D3", "D4", "D5", "D6", "D7", 
"D8", "D9", "DA", "DB", "DC", "00", "00", "DF", 
"E0", "E1", "E2", "E3", "E4", "E5", "E6", "E7", 
"E8", "E9", "00", "EB", "00", "ED", "EE", "00", 
"00", "F1", "F2", "F3", "F4", "F5", "F6", "F7", 
"F8", "F9", "FA", "FB", "FC", "00", "00", "FF", 
};
char latin5_2_sym[128][3] = {
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "D3", "00", "00", "D8", "00", "D2", "00", 
"B0", "B1", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "B4", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "B8", 
"00", "00", "00", "00", "00", "00", "00", "00", 
};
char latin9_2_ansi[128][3] = {
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"A0", "A1", "A2", "A3", "00", "A5", "8A", "A7", 
"9A", "A9", "AA", "AB", "AC", "AD", "AE", "AF", 
"B0", "B1", "B2", "B3", "00", "B5", "B6", "B7", 
"00", "B9", "BA", "BB", "8C", "9C", "9F", "BF", 
"C0", "C1", "C2", "C3", "C4", "C5", "C6", "C7", 
"C8", "C9", "CA", "CB", "CC", "CD", "CE", "CF", 
"D0", "D1", "D2", "D3", "D4", "D5", "D6", "D7", 
"D8", "D9", "DA", "DB", "DC", "DD", "DE", "DF", 
"E0", "E1", "E2", "E3", "E4", "E5", "E6", "E7", 
"E8", "E9", "EA", "EB", "EC", "ED", "EE", "EF", 
"F0", "F1", "F2", "F3", "F4", "F5", "F6", "F7", 
"F8", "F9", "FA", "FB", "FC", "FD", "FE", "FF", 
};
char latin9_2_sym[128][3] = {
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "D3", "00", "00", "D8", "00", "D2", "00", 
"B0", "B1", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "B4", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "B8", 
"00", "00", "00", "00", "00", "00", "00", "00", 
};
char next_2_ansi[128][3] = {
"A0", "C0", "C1", "C2", "C3", "C4", "C5", "C7", 
"C8", "C9", "CA", "CB", "CC", "CD", "CE", "CF", 
"D0", "D1", "D2", "D3", "D4", "D5", "D6", "D9", 
"DA", "DB", "DC", "DD", "DE", "B5", "D7", "F7", 
"A9", "A1", "A2", "A3", "00", "A5", "83", "A7", 
"A4", "92", "93", "AB", "8B", "9B", "00", "00", 
"AE", "96", "86", "87", "B7", "A6", "B6", "95", 
"82", "84", "94", "BB", "85", "89", "AC", "BF", 
"B9", "00", "B4", "88", "98", "AF", "00", "00", 
"A8", "B2", "00", "B8", "B3", "00", "00", "00", 
"97", "B1", "BC", "BD", "BE", "E0", "E1", "E2", 
"E3", "E4", "E5", "E7", "E8", "E9", "EA", "EB", 
"EC", "C6", "ED", "AA", "EE", "EF", "F0", "F1", 
"00", "D8", "8C", "BA", "F2", "F3", "F4", "F5", 
"F6", "E6", "F9", "FA", "FB", "00", "FC", "FD", 
"00", "F8", "9C", "DF", "FE", "FF", "00", "00", 
};
char next_2_sym[128][3] = {
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "B4", "B8", 
"D3", "00", "00", "00", "A4", "00", "A6", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"D2", "00", "00", "00", "00", "00", "00", "B7", 
"00", "00", "00", "00", "BC", "00", "D8", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "B1", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
};

/* Cyrillic Encodings */

char cp1251_2_cp1251[128][3] = {
"80", "81", "82", "83", "84", "85", "86", "87", 
"88", "89", "8A", "8B", "8C", "8D", "8E", "8F", 
"90", "91", "92", "93", "94", "95", "96", "97", 
"00", "99", "9A", "9B", "9C", "9D", "9E", "9F", 
"A0", "A1", "A2", "A3", "A4", "A5", "A6", "A7", 
"A8", "A9", "AA", "AB", "AC", "AD", "AE", "AF", 
"B0", "B1", "B2", "B3", "B4", "B5", "B6", "B7", 
"B8", "B9", "BA", "BB", "BC", "BD", "BE", "BF", 
"C0", "C1", "C2", "C3", "C4", "C5", "C6", "C7", 
"C8", "C9", "CA", "CB", "CC", "CD", "CE", "CF", 
"D0", "D1", "D2", "D3", "D4", "D5", "D6", "D7", 
"D8", "D9", "DA", "DB", "DC", "DD", "DE", "DF", 
"E0", "E1", "E2", "E3", "E4", "E5", "E6", "E7", 
"E8", "E9", "EA", "EB", "EC", "ED", "EE", "EF", 
"F0", "F1", "F2", "F3", "F4", "F5", "F6", "F7", 
"F8", "F9", "FA", "FB", "FC", "FD", "FE", "FF", 
};
char cp855_2_cp1251[128][3] = {
"90", "80", "83", "81", "B8", "A8", "BA", "AA", 
"BE", "BD", "B3", "B2", "BF", "AF", "BC", "A3", 
"9A", "8A", "9C", "8C", "9E", "8E", "9D", "8D", 
"A2", "A1", "9F", "8F", "FE", "DE", "FA", "DA", 
"E0", "C0", "E1", "C1", "F6", "D6", "E4", "C4", 
"E5", "C5", "F4", "D4", "E3", "C3", "AB", "BB", 
"00", "00", "00", "00", "00", "F5", "D5", "E8", 
"C8", "00", "00", "00", "00", "E9", "C9", "00", 
"00", "00", "00", "00", "00", "00", "EA", "CA", 
"00", "00", "00", "00", "00", "00", "00", "A4", 
"EB", "CB", "EC", "CC", "ED", "CD", "EE", "CE", 
"EF", "00", "00", "00", "00", "CF", "FF", "00", 
"DF", "F0", "D0", "F1", "D1", "F2", "D2", "F3", 
"D3", "E6", "C6", "E2", "C2", "FC", "DC", "B9", 
"AD", "FB", "DB", "E7", "C7", "F8", "D8", "FD", 
"DD", "F9", "D9", "F7", "D7", "A7", "00", "A0", 
};
char cp866_2_cp1251[128][3] = {
"C0", "C1", "C2", "C3", "C4", "C5", "C6", "C7", 
"C8", "C9", "CA", "CB", "CC", "CD", "CE", "CF", 
"D0", "D1", "D2", "D3", "D4", "D5", "D6", "D7", 
"D8", "D9", "DA", "DB", "DC", "DD", "DE", "DF", 
"E0", "E1", "E2", "E3", "E4", "E5", "E6", "E7", 
"E8", "E9", "EA", "EB", "EC", "ED", "EE", "EF", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"F0", "F1", "F2", "F3", "F4", "F5", "F6", "F7", 
"F8", "F9", "FA", "FB", "FC", "FD", "FE", "FF", 
"A8", "B8", "AA", "BA", "AF", "BF", "A1", "A2", 
"B0", "95", "B7", "00", "B9", "A4", "00", "A0", 
};
char koi8r_2_cp1251[128][3] = {
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "95", "00", "00", 
"00", "00", "A0", "00", "B0", "00", "B7", "00", 
"00", "00", "00", "B8", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "A8", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "A9", 
"FE", "E0", "E1", "F6", "E4", "E5", "F4", "E3", 
"F5", "E8", "E9", "EA", "EB", "EC", "ED", "EE", 
"EF", "FF", "F0", "F1", "F2", "F3", "E6", "E2", 
"FC", "FB", "E7", "F8", "FD", "F9", "F7", "FA", 
"DE", "C0", "C1", "D6", "C4", "C5", "D4", "C3", 
"D5", "C8", "C9", "CA", "CB", "CC", "CD", "CE", 
"CF", "DF", "D0", "D1", "D2", "D3", "C6", "C2", 
"DC", "DB", "C7", "D8", "DD", "D9", "D7", "DA", 
};
char koi8u_2_cp1251[128][3] = {
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "00", "00", "00", 
"00", "00", "00", "00", "00", "95", "00", "00", 
"00", "00", "A0", "00", "B0", "00", "B7", "00", 
"00", "00", "00", "B8", "BA", "00", "B3", "BF", 
"00", "00", "00", "00", "00", "B4", "00", "00", 
"00", "00", "00", "A8", "AA", "00", "B2", "AF", 
"00", "00", "00", "00", "00", "A5", "00", "A9", 
"FE", "E0", "E1", "F6", "E4", "E5", "F4", "E3", 
"F5", "E8", "E9", "EA", "EB", "EC", "ED", "EE", 
"EF", "FF", "F0", "F1", "F2", "F3", "E6", "E2", 
"FC", "FB", "E7", "F8", "FD", "F9", "F7", "FA", 
"DE", "C0", "C1", "D6", "C4", "C5", "D4", "C3", 
"D5", "C8", "C9", "CA", "CB", "CC", "CD", "CE", 
"CF", "DF", "D0", "D1", "D2", "D3", "C6", "C2", 
"DC", "DB", "C7", "D8", "DD", "D9", "D7", "DA", 
};
char maccyr_2_cp1251[128][3] = {
"C0", "C1", "C2", "C3", "C4", "C5", "C6", "C7", 
"C8", "C9", "CA", "CB", "CC", "CD", "CE", "CF", 
"D0", "D1", "D2", "D3", "D4", "D5", "D6", "D7", 
"D8", "D9", "DA", "DB", "DC", "DD", "DE", "DF", 
"86", "B0", "A5", "00", "A7", "95", "B6", "B2", 
"AE", "A9", "99", "80", "90", "00", "81", "83", 
"00", "B1", "00", "00", "B3", "B5", "B4", "A3", 
"AA", "BA", "AF", "BF", "8A", "9A", "8C", "9C", 
"BC", "BD", "AC", "00", "00", "00", "00", "AB", 
"BB", "85", "A0", "8E", "9E", "8D", "9D", "BE", 
"96", "97", "93", "94", "91", "92", "00", "84", 
"A1", "A2", "8F", "9F", "B9", "A8", "B8", "FF", 
"E0", "E1", "E2", "E3", "E4", "E5", "E6", "E7", 
"E8", "E9", "EA", "EB", "EC", "ED", "EE", "EF", 
"F0", "F1", "F2", "F3", "F4", "F5", "F6", "F7", 
"F8", "F9", "FA", "FB", "FC", "FD", "FE", "88", 
};
char macukr_2_cp1251[128][3] = {
"C0", "C1", "C2", "C3", "C4", "C5", "C6", "C7", 
"C8", "C9", "CA", "CB", "CC", "CD", "CE", "CF", 
"D0", "D1", "D2", "D3", "D4", "D5", "D6", "D7", 
"D8", "D9", "DA", "DB", "DC", "DD", "DE", "DF", 
"86", "B0", "A5", "00", "A7", "95", "B6", "B2", 
"AE", "A9", "99", "80", "90", "00", "81", "83", 
"00", "B1", "00", "00", "B3", "B5", "B4", "A3", 
"AA", "BA", "AF", "BF", "8A", "9A", "8C", "9C", 
"BC", "BD", "AC", "00", "00", "00", "00", "AB", 
"BB", "85", "A0", "8E", "9E", "8D", "9D", "BE", 
"96", "97", "93", "94", "91", "92", "00", "84", 
"A1", "A2", "8F", "9F", "B9", "A8", "B8", "FF", 
"E0", "E1", "E2", "E3", "E4", "E5", "E6", "E7", 
"E8", "E9", "EA", "EB", "EC", "ED", "EE", "EF", 
"F0", "F1", "F2", "F3", "F4", "F5", "F6", "F7", 
"F8", "F9", "FA", "FB", "FC", "FD", "FE", "A4", 
};
